==> projectx-sdk-1.0.58-sources.jar: cn/com/duiba/projectx/sdk/component/bindphone/param/SendSmsCodeParam.java <==
package cn.com.duiba.projectx.sdk.component.bindphone.param;

import java.util.concurrent.TimeUnit;

/**
 * @program: projectx
 * @description: 发送短信验证码入参
 * @author: Simba
 * @create: 2021-03-18 10:40
 **/
public class SendSmsCodeParam {

    /**
     * 玩法id
     */
    private String playwayId;
    /**
     * 分组名称-根据业务而定 可不传
     */
    private String groupName;
    /**
     * 发送验证码手机号
     */
    private String phoneNumber;
    /**
     * 验证码长度 支持4-10位内自定义
     * 超出或小于则按照4/10生成
     */
    private int codeLength;
    /**
     * 验证码有效时间 默认10分钟内有效
     */
    private int expireTime = 10;
    /**
     * 验证码有效时间单位
     */
    private TimeUnit expireTimeUnit = TimeUnit.MINUTES;
    /**
     * 滑块校验结果
     */
    private String validate;

    public String getPlaywayId() {
        return playwayId;
    }

    public void setPlaywayId(String playwayId) {
        this.playwayId = playwayId;
    }

    public String getGroupName() {
        return groupName;
    }

    public void setGroupName(String groupName) {
        this.groupName = groupName;
    }

    public String getPhoneNumber() {
        return phoneNumber;
    }

    public void setPhoneNumber(String phoneNumber) {
        this.phoneNumber = phoneNumber;
    }

    public int getCodeLength() {
        return codeLength;
    }

    public void setCodeLength(int codeLength) {
        this.codeLength = codeLength;
    }

    public int getExpireTime() {
        return expireTime;
    }

    public void setExpireTime(int expireTime) {
        this.expireTime = expireTime;
    }

    public TimeUnit getExpireTimeUnit() {
        return expireTimeUnit;
    }

    public void setExpireTimeUnit(TimeUnit expireTimeUnit) {
        this.expireTimeUnit = expireTimeUnit;
    }

    public String getValidate() {
        return validate;
    }

    public void setValidate(String validate) {
        this.validate = validate;
    }
}

==> projectx-sdk-1.1.90-sources.jar: cn/com/duiba/projectx/sdk/component/bindphone/param/SendSmsCodeParam.java <==
package cn.com.duiba.projectx.sdk.component.bindphone.param;

import java.util.concurrent.TimeUnit;

/**
 * @program: projectx
 * @description: 发送短信验证码入参
 * @author: Simba
 * @create: 2021-03-18 10:40
 **/
public class SendSmsCodeParam {

    /**
     * 玩法id
     */
    private String playwayId;
    /**
     * 分组名称-根据业务而定 可不传
     */
    private String groupName;
    /**
     * 发送验证码手机号
     */
    private String phoneNumber;
    /**
     * 验证码长度 支持4-10位内自定义
     * 超出或小于则按照4/10生成
     */
    private int codeLength;
    /**
     * 验证码有效时间 默认10分钟内有效
     */
    private int expireTime = 10;
    /**
     * 验证码有效时间单位
     */
    private TimeUnit expireTimeUnit = TimeUnit.MINUTES;
    /**
     * 滑块校验结果
     */
    private String validate;

    /**
     * 滑块校验值
     */
    private String slideValidate;

    public String getPlaywayId() {
        return playwayId;
    }

    public void setPlaywayId(String playwayId) {
        this.playwayId = playwayId;
    }

    public String getGroupName() {
        return groupName;
    }

    public void setGroupName(String groupName) {
        this.groupName = groupName;
    }

    public String getPhoneNumber() {
        return phoneNumber;
    }

    public void setPhoneNumber(String phoneNumber) {
        this.phoneNumber = phoneNumber;
    }

    public int getCodeLength() {
        return codeLength;
    }

    public void setCodeLength(int codeLength) {
        this.codeLength = codeLength;
    }

    public int getExpireTime() {
        return expireTime;
    }

    public void setExpireTime(int expireTime) {
        this.expireTime = expireTime;
    }

    public TimeUnit getExpireTimeUnit() {
        return expireTimeUnit;
    }

    public void setExpireTimeUnit(TimeUnit expireTimeUnit) {
        this.expireTimeUnit = expireTimeUnit;
    }

    public String getValidate() {
        return validate;
    }

    public void setValidate(String validate) {
        this.validate = validate;
    }

    public String getSlideValidate() {
        return slideValidate;
    }

    public void setSlideValidate(String slideValidate) {
        this.slideValidate = slideValidate;
    }
}
